@@ -18,11 +18,11 @@ __init__.py
 
 from apafib.datasets import fetch_apa_data, load_BCN_IBEX, load_BCN_UK, load_BCN_vuelos, \
      load_medical_costs, load_stroke, load_wind_prediction, load_titanic, load_crabs, \
-          load_life_expectancy, load_electric_devices 
+          load_life_expectancy, load_electric_devices, load_energy 
 
 from apafib.classifiers import BlackBoxClassifier, BlackBoxRegressor
 
-__version__ = '0.0.9'
+__version__ = '0.0.11'
 
 __all__ = ['fetch_apa_data', 
            'BlackBoxClassifier', 
@@ -36,5 +36,6 @@ __all__ = ['fetch_apa_data',
            'load_titanic',
            'load_crabs',
            'load_life_expectancy', 
-           'load_electric_devices'
+           'load_electric_devices',
+           'load_energy'
            ]
\ No newline at end of file
