@@ -96,9 +96,13 @@ def load_life_expectancy():
 
 def load_electric_devices():
     data =  pd.read_csv(f'{DATALINK}/ElectricDevices_TRAIN.csv', header=None, na_values='?')
+    data['Class'] = data['Class'] -1
     data.columns = ['Class'] + [f'H{i:02d}:{j}' for i in range(24) for j in ['00', '15', '30', '45']]
     return data
 
+def load_energy():
+    return fetch_dataset('Energy')
+
 
 
 
